#  tests for pyhive-0.6.1-py310h06a4308_0 (this is a generated file);
print('===== testing package: pyhive-0.6.1-py310h06a4308_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from pyhive import hive
#  --- run_test.py (end) ---

print('===== pyhive-0.6.1-py310h06a4308_0 OK =====');
print("import: 'pyhive'")
import pyhive

print("import: 'TCLIService'")
import TCLIService

